==> react-router-bootstrap-0.21.0.jar: META-INF/resources/webjars/react-router-bootstrap/0.21.0/CHANGELOG.md <==
## [v0.21.0]
> 2016-04-11

- **Breaking:** Move from React Router to rrtr ([#155])

[v0.21.0]: https://github.com/react-bootstrap/react-router-bootstrap/compare/v0.20.1...v0.21.0
[#155]: https://github.com/react-bootstrap/react-router-bootstrap/pull/155


v0.20.1 - Mon, 11 Jan 2016 16:55:18 GMT
---------------------------------------





v0.20.0 - Thu, 31 Dec 2015 18:45:45 GMT
---------------------------------------

- [483a863](../../commit/483a863) [changed] Support React Router v2.x



v0.19.3 - Wed, 28 Oct 2015 15:11:30 GMT
---------------------------------------

- [d1306b1](../../commit/d1306b1) [fixed] Support LinkContainer without history
- [5ca61cf](../../commit/5ca61cf) [added] Support hash prop on LinkContainer



v0.19.2 - Fri, 09 Oct 2015 18:02:47 GMT
---------------------------------------

- [f80082b](../../commit/f80082b) [fixed] bower building and publishing



v0.19.1 - Fri, 09 Oct 2015 14:17:56 GMT
---------------------------------------

- [c76b88c](../../commit/c76b88c) [added] Support onClick on child



v0.19.0 - Tue, 15 Sep 2015 17:33:35 GMT
---------------------------------------

- [ac500c8](../../commit/ac500c8) [changed] Replace everything with LinkContainer



v0.18.1 - Mon, 10 Aug 2015 21:56:38 GMT
---------------------------------------

- [4365680](../../commit/4365680) [added] PageItem links support
- [f86272d](../../commit/f86272d) [added] Thumbnail links support



v0.18.0 - Thu, 23 Jul 2015 02:07:27 GMT
---------------------------------------

- [5100b0b](../../commit/5100b0b) [removed] RouterModalTrigger removed upstream
- [7e15213](../../commit/7e15213) [fixed] visual testing



v0.17.2 - Sun, 12 Jul 2015 15:50:59 GMT
---------------------------------------

- [5f16463](../../commit/5f16463) [fixed] Remove extraneous dependencies.

==> react-router-bootstrap-0.23.0.jar: META-INF/resources/webjars/react-router-bootstrap/0.23.0/CHANGELOG.md <==
## [v0.23.0]
> 2016-04-28

- **Breaking:** Drop explicit handling of `disabled`, as React-Bootstrap now takes care of this ([#164])
- **Minor:** Upgrade to Babel 6 ([#164])

[v0.23.0]: https://github.com/react-bootstrap/react-router-bootstrap/compare/v0.22.1...v0.23.0
[#164]: https://github.com/react-bootstrap/react-router-bootstrap/pull/164


## [v0.22.1]
> 2016-04-13

- **Minor:** Republish to update README on npm

[v0.22.1]: https://github.com/react-bootstrap/react-router-bootstrap/compare/v0.22.0...v0.22.1


## [v0.22.0]
> 2016-04-12

- **Breaking:** Move from rrtr to React Router ([#160])

[v0.22.0]: https://github.com/react-bootstrap/react-router-bootstrap/compare/v0.21.0...v0.22.0
[#160]: https://github.com/react-bootstrap/react-router-bootstrap/pull/160


## [v0.21.0]
> 2016-04-11

- **Breaking:** Move from React Router to rrtr ([#155])

[v0.21.0]: https://github.com/react-bootstrap/react-router-bootstrap/compare/v0.20.1...v0.21.0
[#155]: https://github.com/react-bootstrap/react-router-bootstrap/pull/155


v0.20.1 - Mon, 11 Jan 2016 16:55:18 GMT
---------------------------------------





v0.20.0 - Thu, 31 Dec 2015 18:45:45 GMT
---------------------------------------

- [483a863](../../commit/483a863) [changed] Support React Router v2.x



v0.19.3 - Wed, 28 Oct 2015 15:11:30 GMT
---------------------------------------

- [d1306b1](../../commit/d1306b1) [fixed] Support LinkContainer without history
- [5ca61cf](../../commit/5ca61cf) [added] Support hash prop on LinkContainer



v0.19.2 - Fri, 09 Oct 2015 18:02:47 GMT
---------------------------------------

- [f80082b](../../commit/f80082b) [fixed] bower building and publishing



v0.19.1 - Fri, 09 Oct 2015 14:17:56 GMT
---------------------------------------

- [c76b88c](../../commit/c76b88c) [added] Support onClick on child



v0.19.0 - Tue, 15 Sep 2015 17:33:35 GMT
---------------------------------------

- [ac500c8](../../commit/ac500c8) [changed] Replace everything with LinkContainer



v0.18.1 - Mon, 10 Aug 2015 21:56:38 GMT
---------------------------------------

- [4365680](../../commit/4365680) [added] PageItem links support
- [f86272d](../../commit/f86272d) [added] Thumbnail links support



v0.18.0 - Thu, 23 Jul 2015 02:07:27 GMT
---------------------------------------

- [5100b0b](../../commit/5100b0b) [removed] RouterModalTrigger removed upstream
- [7e15213](../../commit/7e15213) [fixed] visual testing



v0.17.2 - Sun, 12 Jul 2015 15:50:59 GMT
---------------------------------------

- [5f16463](../../commit/5f16463) [fixed] Remove extraneous dependencies.
